# neuro_pypes

[![image](https://readthedocs.org/projects/neuro-pypes/badge/?version=latest)](http://neuro-pypes.readthedocs.io)
[![DOI](https://zenodo.org/badge/46623736.svg)](https://zenodo.org/badge/latestdoi/46623736)

Reusable neuroimaging pipelines using [nipype](http://nipype.readthedocs.io/) and state-of-the-art
neuroimaging preprocessing software.

The objectives of this projects are:

- easy-to-use, complete, reusable, and configurable pre-processing pipelines, and
- high-quality results with the minimum manual intervention in the images.


## Documentation

Please have a look at the documentation [here](http://neuro-pypes.readthedocs.io).

## Citation

If you use Pypes please cite it:

```
Alexandre M. Savio, Michael Schutte, Manuel Graña and Igor Yakushev
Pypes: Workflows for Processing Multimodal Neuroimaging Data
Front. Neuroinform., April 2017, vol 11, 2017, pages 25
issn: 1662-5196
doi: 10.3389/finf.2017.00025
```
[https://doi.org/10.3389/fninf.2017.00025](https://doi.org/10.3389/fninf.2017.00025)

...or the BibTeX:
```
@ARTICLE{10.3389/fninf.2017.00025,
AUTHOR={Savio, Alexandre M. and Schutte, Michael and Graña, Manuel and Yakushev, Igor},
TITLE={Pypes: Workflows for Processing Multimodal Neuroimaging Data},
JOURNAL={Frontiers in Neuroinformatics},
VOLUME={11},
PAGES={25},
YEAR={2017},
URL={http://journal.frontiersin.org/article/10.3389/fninf.2017.00025},
DOI={10.3389/fninf.2017.00025},
ISSN={1662-5196}
}
```
Also consider citing [Nipype](http://nipype.readthedocs.io) and all the other open source tools you use.

## License

Licensed under the Apache License, Version 2.0.
